-----------------------------------------------------------------------------------------------
-- Client Lua Script for PerbMedicResource
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
local PerbMedicResource = {}

require "GameLib"
require "Unit"

function PerbMedicResource:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self
    return o
end

function PerbMedicResource:Init()
    Apollo.RegisterAddon(self)
end

function PerbMedicResource:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("PerbMedicResource.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

function PerbMedicResource:OnDocLoaded()
	if self.xmlDoc == nil then return end	
	Apollo.LoadSprites("BorderSprite.xml", "Perb")
	self.wndMain = Apollo.LoadForm(self.xmlDoc, 							"PerbMedicResourceForm", "FixedHudStratum", self)
	Apollo.RegisterEventHandler("UnitEnteredCombat", 						"RedrawVisiblity", self)
	Apollo.RegisterEventHandler("PlayerChanged", 							"RedrawVisiblity", self)
	Apollo.RegisterEventHandler("WindowSizeChanged", 						"RedrawVisiblity", self)
	Apollo.RegisterEventHandler("OptionsUpdated_HUDPreferences", 			"RedrawVisiblity", self)
	Apollo.RegisterEventHandler("PlayerLevelChange", 						"RedrawVisiblity", self)
	Apollo.RegisterEventHandler("VarChange_FrameCount", 					"OnFrame", self)
	Apollo.RegisterEventHandler("WindowManagementReady", 					"OnWindowManagementReady", self)
	Apollo.RegisterEventHandler("WindowManagementUpdate",					"OnWindowManagementUpdate", self)
	
	self:RedrawVisiblity()
end

function PerbMedicResource:OnWindowManagementReady()
    Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndMain, strName = "PerbMedicResource"})
end

function PerbMedicResource:OnWindowManagementUpdate()
    local bMoveable = self.wndMain:IsStyleOn("Moveable")

	self.wndMain:SetStyle("Sizable", bMoveable)
	self.wndMain:SetStyle("RequireMetaKeyToMove", bMoveable)
    self.wndMain:SetStyle("IgnoreMouse", not bMoveable)
end

function PerbMedicResource:OnFrame()
	local unitPlayer = GameLib.GetPlayerUnit()
	local nManaMax = unitPlayer:GetMaxMana()
	local nManaCurrent = unitPlayer:GetMana()
	local nResourceCurrent = unitPlayer:GetResource(1)
	local nResourceMax = unitPlayer:GetMaxResource(1)

	self.wndMain:FindChild("Manabar"):SetMax(nManaMax)
	self.wndMain:FindChild("Manabar"):SetProgress(nManaCurrent)
	self.wndMain:FindChild("ManaText"):SetText(math.floor(nManaCurrent))
	self.wndMain:FindChild("bar1"):SetMax(3)
	self.wndMain:FindChild("bar2"):SetMax(3)
	self.wndMain:FindChild("bar3"):SetMax(3)
	self.wndMain:FindChild("bar4"):SetMax(3)

	local tBuffs = unitPlayer:GetBuffs()
	local nPartialCount = 0
	
	for idx, tCurrBuffData in pairs(tBuffs.arBeneficial or {}) do
		if tCurrBuffData.splEffect:GetId() == 42569 then
			nPartialCount = tCurrBuffData.nCount
			break
		end
	end
	
	for idx = 1, 4 do
		if idx <= nResourceCurrent then
			self.wndMain:FindChild("bar" .. idx):SetProgress(3)
			self.wndMain:FindChild("bar" .. idx):SetBarColor("xkcdBoringGreen")
		elseif idx == nResourceCurrent + 1 then
			self.wndMain:FindChild("bar" .. idx):SetProgress(nPartialCount)
			self.wndMain:FindChild("bar" .. idx):SetBarColor("xkcdJungleGreen")
		else
			self.wndMain:FindChild("bar" .. idx):SetProgress(0)
		end		
	end
end

function PerbMedicResource:RedrawVisiblity()
	local unitPlayer = GameLib.GetPlayerUnit()
	local nVisibility = Apollo.GetConsoleVariable("hud.resourceBarDisplay")
	
	if nVisibility == 1 then --always on
		self.wndMain:Show(true)
	elseif nVisibility == 2 then --always off
		self.wndMain:Show(false)
	elseif nVisibility == 3 then --on in combat
		self.wndMain:Show(unitPlayer and unitPlayer:IsInCombat())
	elseif nVisibility == 4 then --on out of combat
		self.wndMain:Show(unitPlayer and not unitPlayer:IsInCombat())
	else --unspesified (on)
		self.wndMain:Show(true)
	end
end

local PerbMedicResourceInst = PerbMedicResource:new()
PerbMedicResourceInst:Init()